@@ -1,4 +1,4 @@
-#include "normalize.h"
+#include <slope/normalize.h>
 
 namespace slope {
 
